==> im-sdk_11.4.1483.orig.tar.gz: im-sdk-r11_4-1483/iiimxcf/xiiimp.so/iiimp/iiimpAuxP.h <==
/*
Copyright 1990-2001 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/

/*
 * $Id: iiimpAuxP.h,v 1.1.1.1.2.1 2001/03/15 07:52:16 himi Exp $
 */

#ifndef _IIIMP_AUX_P_H
#define _IIIMP_AUX_P_H

#pragma ident	"@(#)iiimpAuxP.h 1.3	99/07/28 SMI"

#include <iiimcf.h>
#include "iiimpAux.h"

typedef struct _aux_entry {
    int	created;
    aux_dir_t dir;
    struct _aux_entry *next;
} aux_entry_t;


typedef struct _aux_handle {
    aux_name_t aux_name;
    char *file_name;
    void *handle;
    aux_entry_t *ae;
    int	ae_num;
    struct _aux_handle *next;
} aux_handle_t;


struct _aux_im_data {
    int	im_id;
    int	ic_id;
    aux_entry_t *ae;
    void *data;
    aux_im_data_t *next;
};

extern void IIimpAuxDownload(
    IIIMCF_downloaded_object obj
);
extern void IIimpAuxStart(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpAuxDraw(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpAuxDone(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpDestroryAuxData(
    XicCommon ic
);
extern void IIimpFreeAllAuxData();

#endif /* !_IIIMP_AUX_P_H */

/* Local Variables: */
/* c-file-style: "iiim-project" */
/* End: */

==> im-sdk_11.4.1870.orig.tar.gz: im-sdk-r11_4-1870/iiimxcf/xiiimp.so/iiimp/iiimpAuxP.h <==
/*
Copyright 1990-2001 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/

/*
 * $Id: iiimpAuxP.h,v 1.1.1.1.2.1 2001/03/15 07:52:16 himi Exp $
 */

#ifndef _IIIMP_AUX_P_H
#define _IIIMP_AUX_P_H

#pragma ident	"@(#)iiimpAuxP.h 1.3	99/07/28 SMI"

#include <iiimcf.h>
#include "iiimpAux.h"

extern void IIimpAuxDownload(
    IIIMCF_downloaded_object obj
);
extern void IIimpAuxStart(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpAuxDraw(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpAuxDone(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpAuxGetValuesReply(
    XicCommon ic,
    IIIMCF_event ev
);
extern void IIimpDestroryAuxData(
    XicCommon ic
);
extern void IIimpFreeAllAuxData();
extern void IIimpAuxSetICFocus(
    XicCommon ic
);
extern void IIimpAuxUnsetICFocus(
    XicCommon ic
);

#endif /* !_IIIMP_AUX_P_H */

/* Local Variables: */
/* c-file-style: "iiim-project" */
/* End: */
